"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.header = void 0;
const path = __importStar(require("path"));
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function header(context, page) {
    const isPackages = context.options.getValue('entryPointStrategy') ===
        typedoc_1.EntryPointStrategy.Packages;
    if (isPackages) {
        const packageItem = findPackage(page.model);
        if (packageItem) {
            return packageHeader(context, page);
        }
    }
    return projectHeader(context, page);
}
exports.header = header;
function projectHeader(context, page) {
    const fileExtension = context.options.getValue('useMDXFileExt')
        ? '.mdx'
        : '.md';
    const entryFileName = `${path.parse(context.options.getValue('entryFileName')).name}${fileExtension}`;
    const titleLink = context.options.getValue('titleLink');
    const md = [];
    const title = context.helpers.getIndexTitle(context.text.getText('header.title'), page.project.name, page.project.packageVersion);
    const readmeLabel = context.text.getText('header.readme');
    const indexLabel = context.text.getText('header.docs');
    md.push(titleLink ? (0, markdown_1.bold)((0, markdown_1.link)(title, titleLink)) : (0, markdown_1.bold)(title));
    md.push('•');
    const preserveReadme = Boolean(page.project.readme) && !context.options.getValue('mergeReadme');
    const useEntryModule = (page.project?.groups &&
        Boolean(page.project?.groups[0]?.children.find((child) => child.name === context.options.getValue('entryModule')))) ||
        false;
    if (preserveReadme) {
        const links = [];
        const readMeUrl = useEntryModule
            ? `readme_${fileExtension}`
            : entryFileName;
        if (page.url === readMeUrl) {
            links.push(readmeLabel);
        }
        else {
            links.push(context.partials.linkTo(readmeLabel, readMeUrl));
        }
        links.push('\\|');
        const indexUrl = useEntryModule ? entryFileName : page.project.url;
        if (page.url === indexUrl) {
            links.push(indexLabel);
        }
        else {
            links.push(context.partials.linkTo(indexLabel, indexUrl));
        }
        md.push(`${links.join(' ')}`);
    }
    else {
        if (useEntryModule || page.url === page.project.url) {
            md.push(indexLabel);
        }
        else {
            md.push(context.partials.linkTo(indexLabel, page.project.url));
        }
    }
    return `${md.join(' ')}\n\n***\n`;
}
function packageHeader(context, page) {
    const packageItem = findPackage(page.model);
    if (!packageItem) {
        return '';
    }
    const md = [];
    const readmeLabel = context.text.getText('header.readme');
    const indexLabel = context.text.getText('header.docs');
    const fileExtension = context.options.getValue('useMDXFileExt')
        ? '.mdx'
        : '.md';
    const entryFileName = `${path.parse(context.options.getValue('entryFileName')).name}${fileExtension}`;
    const packageItemName = packageItem.packageVersion
        ? `${packageItem.name} v${packageItem.packageVersion}`
        : packageItem.name;
    md.push((0, markdown_1.bold)(packageItemName));
    md.push('•');
    const preservePackageReadme = Boolean(packageItem.readme) && !context.options.getValue('mergeReadme');
    if (preservePackageReadme) {
        const links = [];
        const readmeUrl = `${packageItem.name}/${entryFileName}`;
        if (page.url === readmeUrl) {
            links.push(readmeLabel);
        }
        else {
            links.push(context.partials.linkTo(readmeLabel, readmeUrl));
        }
        links.push('\\|');
        if (page.url === packageItem.url) {
            links.push(indexLabel);
        }
        else {
            links.push(context.partials.linkTo(indexLabel, packageItem.url));
        }
        md.push(`${links.join(' ')}`);
    }
    else {
        md.push(indexLabel);
    }
    return `${md.join(' ')}\n\n***\n`;
}
function findPackage(model) {
    if (model.kind === typedoc_1.ReflectionKind.Module &&
        model.parent?.kind === typedoc_1.ReflectionKind.Project) {
        return model;
    }
    if (model.parent) {
        return findPackage(model.parent);
    }
    return null;
}
