"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.declarationMemberIdentifier = void 0;
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function declarationMemberIdentifier(context, reflection) {
    const md = [];
    const useCodeBlocks = context.options.getValue('useCodeBlocks');
    const declarationType = context.helpers.getDeclarationType(reflection);
    const prefix = [];
    if (reflection.flags.length) {
        prefix.push(reflection.flags
            .map((flag) => (0, markdown_1.bold)((0, markdown_1.backTicks)(flag.toLowerCase())))
            .join(' '));
    }
    if (reflection.flags.isRest) {
        prefix.push('...');
    }
    const keyword = context.helpers.getKeyword(reflection.kind);
    if (useCodeBlocks && context.helpers.isGroupKind(reflection) && keyword) {
        prefix.push(keyword);
    }
    if (prefix.length) {
        md.push(prefix.join(' ') + ' ');
    }
    const name = [];
    if (reflection.getSignature) {
        name.push((0, markdown_1.backTicks)('get') + ' ');
    }
    if (reflection.setSignature) {
        name.push((0, markdown_1.backTicks)('set') + ' ');
    }
    const nameParts = reflection.name.split('.');
    name.push((0, markdown_1.bold)((0, utils_1.escapeChars)(reflection.escapedName?.includes('.')
        ? reflection.name
        : nameParts[nameParts.length - 1])));
    if (reflection.typeParameters) {
        name.push(`\\<${reflection.typeParameters
            ?.map((typeParameter) => (0, markdown_1.backTicks)(typeParameter.name))
            .join(', ')}\\>`);
    }
    if (declarationType) {
        name.push(': ');
    }
    md.push(name.join(''));
    if (declarationType) {
        md.push(context.partials.someType(declarationType));
    }
    if (reflection.defaultValue && reflection.defaultValue !== '...') {
        md.push(` = \`${(0, utils_1.stripComments)(reflection.defaultValue)}\``);
    }
    if (useCodeBlocks) {
        md.push(';');
    }
    const result = md.join('');
    return useCodeBlocks ? (0, markdown_1.codeBlock)(result) : `> ${result}`;
}
exports.declarationMemberIdentifier = declarationMemberIdentifier;
