"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signatureParameters = void 0;
const typedoc_1 = require("typedoc");
const markdown_1 = require("../markdown");
function signatureParameters(context, parameters) {
    const format = context.options.getValue('useCodeBlocks');
    const firstOptionalParamIndex = parameters.findIndex((parameter) => parameter.flags.isOptional);
    return ('(' +
        parameters
            .map((param, i) => {
            const paramsmd = [];
            if (param.flags.isRest) {
                paramsmd.push('...');
            }
            const paramType = context.partials.someType(param.type);
            const showParamType = context.options.getValue('expandParameters');
            const paramItem = [
                `${(0, markdown_1.backTicks)(param.name)}${param.flags.isOptional ||
                    (firstOptionalParamIndex !== -1 && i > firstOptionalParamIndex)
                    ? '?'
                    : ''}`,
            ];
            if (showParamType) {
                paramItem.push(param.type instanceof typedoc_1.ReflectionType
                    ? (0, markdown_1.indentBlock)(paramType)
                    : paramType);
            }
            paramsmd.push(`${format && parameters.length > 2 ? `\n   ` : ''}${paramItem.join(': ')}`);
            return paramsmd.join('');
        })
            .join(`, `) +
        ')');
}
exports.signatureParameters = signatureParameters;
