"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typeDeclarationTable = void 0;
const markdown_1 = require("../markdown");
const utils_1 = require("../utils");
function typeDeclarationTable(context, props) {
    const headers = [];
    const declarations = context.helpers.flattenDeclarations(props, true);
    const hasComments = declarations.some((declaration) => Boolean(declaration.comment));
    const hasDefaultValues = declarations.some((declaration) => Boolean(declaration.defaultValue));
    headers.push(context.text.getText('label.member'));
    headers.push(context.text.getText('label.type'));
    if (hasDefaultValues) {
        headers.push(context.text.getText('label.value'));
    }
    if (hasComments) {
        headers.push(context.text.getText('label.description'));
    }
    const rows = [];
    declarations.forEach((declaration, index) => {
        const row = [];
        row.push((0, utils_1.formatTableNameCol)(declaration.name));
        row.push(context.partials
            .someType(declaration.type)
            .replace(/\n/g, ' '));
        if (hasDefaultValues) {
            row.push((0, utils_1.escapeChars)(!declaration.defaultValue || declaration.defaultValue === '...'
                ? '-'
                : declaration.defaultValue));
        }
        if (hasComments) {
            const comments = declaration.comment;
            if (comments) {
                row.push((0, utils_1.formatTableDescriptionCol)(context.partials.comment(comments)));
            }
            else {
                row.push('-');
            }
        }
        rows.push(row);
    });
    return (0, markdown_1.table)(headers, rows);
}
exports.typeDeclarationTable = typeDeclarationTable;
