import { Options, Reflection } from 'typedoc';
import { MarkdownPageEvent, MarkdownTheme } from '..';
import { MarkdownRendererHooks } from '../plugin/types';
/**
 * The render context of the {@link MarkdownTheme}.
 * This follows the implementation of TypeDocs [DefaultThemeRenderContext](https://typedoc.org/api/classes/DefaultThemeRenderContext.html)
 */
export declare class MarkdownThemeRenderContext {
    private theme;
    readonly page: MarkdownPageEvent<Reflection> | null;
    readonly options: Options;
    /**
     * @param page The page this context is created for.
     * @param options The options used by TypeDoc. See TypeDoc's {@link typedoc!Options | Options} Class.
     */
    constructor(theme: MarkdownTheme, page: MarkdownPageEvent<Reflection> | null, options: Options);
    /**
     * A set of methods to return strings from specific TypeDoc models.
     *
     * These can be consumed by theme templates and partials using the syntax `context.models.method()`.
     */
    helpers: {
        flattenDeclarations: typeof import("./resources/helpers").flattenDeclarations;
        getDeclarationType: typeof import("./resources/helpers").getDeclarationType;
        getIndexTitle: typeof import("./resources/helpers").getIndexTitle;
        getKeyword: typeof import("./resources/helpers").getKeyword;
        getModifier: typeof import("./resources/helpers").getModifier;
        getParameterDefaultValue: typeof import("./resources/helpers").getParameterDefaultValue;
        isGroupKind: typeof import("./resources/helpers").isGroupKind;
        parseComments: typeof import("./resources/helpers").parseComments;
        parseUrl: typeof import("./resources/helpers").parseUrl;
    };
    /**
     * The theme's global templates context.
     */
    templates: {
        memberTemplate: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection>) => string;
        projectTemplate: (page: MarkdownPageEvent<import("typedoc").ProjectReflection>) => string;
        readmeTemplate: (page: MarkdownPageEvent<import("typedoc").ProjectReflection>) => string;
        reflectionTemplate: (page: MarkdownPageEvent<import("typedoc").DeclarationReflection>) => string;
    };
    /**
     * The theme's global partials context.
     */
    partials: any;
    /**
     * Themes text content
     */
    text: {
        getText: (key: keyof import("..").TextContentMappings) => string;
        getTextFromKindString: (kindString: string, isPlural?: boolean) => string;
    };
    /**
     * Hook into the TypeDoc rendering system.
     */
    hook: (name: keyof MarkdownRendererHooks) => string[];
}
